@@ -6,6 +6,7 @@
 Module to manage top level AWS CodeGuru profiles
 """
 
+from compose_x_common.compose_x_common import keyisset
 from troposphere import GetAtt, Ref
 
 from ecs_composex.codeguru_profiler.codeguru_profiler_perms import ACCESS_TYPES
@@ -18,7 +19,13 @@ from ecs_composex.cognito_userpool.cognito_params import (
     USERPOOL_ID,
 )
 from ecs_composex.common import build_template
-from ecs_composex.common.compose_resources import XResource, set_resources
+from ecs_composex.common.compose_resources import (
+    XResource,
+    set_lookup_resources,
+    set_new_resources,
+    set_resources,
+    set_use_resources,
+)
 from ecs_composex.common.stacks import ComposeXStack
 
 
@@ -39,9 +46,6 @@ class UserPool(XResource):
 
     policies_scaffolds = ACCESS_TYPES
 
-    def __init__(self, name, definition, module_name, settings):
-        super().__init__(name, definition, module_name, settings)
-
     def init_outputs(self):
         self.output_properties = {
             USERPOOL_ID: (self.logical_name, self.cfn_resource, Ref, None),
@@ -61,16 +65,15 @@ class XStack(ComposeXStack):
 
     def __init__(self, title, settings, **kwargs):
         """
-        :param title:
+        :param str title:
         :param ecs_composex.common.settings.ComposeXSettings settings:
-        :param kwargs:
+        :param dict kwargs:
         """
-        set_resources(settings, UserPool, RES_KEY, MOD_KEY)
-        new_resources = [
-            res
-            for res in settings.compose_content[RES_KEY].values()
-            if not res.lookup and not res.use
-        ]
+        set_resources(settings, UserPool, RES_KEY, MOD_KEY, mapping_key=MAPPINGS_KEY)
+        x_resources = settings.compose_content[RES_KEY].values()
+        new_resources = set_new_resources(x_resources, RES_KEY, False)
+        lookup_resources = set_lookup_resources(x_resources, RES_KEY)
+        use_resources = set_use_resources(x_resources, RES_KEY, False)
         if new_resources:
             stack_template = create_root_template(new_resources)
             super().__init__(title, stack_template, **kwargs)
@@ -78,13 +81,8 @@ class XStack(ComposeXStack):
             self.is_void = True
         for resource in settings.compose_content[RES_KEY].values():
             resource.stack = self
-        lookup_resources = [
-            res
-            for res in settings.compose_content[RES_KEY].values()
-            if res.lookup and not res.use and not res.properties
-        ]
         for res in lookup_resources:
-            self.mappings[res.logical_name] = lookup_userpool_config(
-                res.lookup, settings.session
-            )
-        settings.mappings[MAPPINGS_KEY] = self.mappings
+            if not keyisset(RES_KEY, settings.mappings):
+                settings.mappings[RES_KEY] = {}
+            res.mappings = lookup_userpool_config(res.lookup, settings.session)
+            settings.mappings[RES_KEY].update({res.logical_name: res.mappings})
