@@ -44,8 +44,11 @@ USE_HOSTNAME_CON_T = "UseMicroserviceHostnameCondition"
 USE_HOSTNAME_CON = Not(Condition(NOT_USE_HOSTNAME_CON_T))
 
 USE_CLUSTER_CAPACITY_PROVIDERS_CON_T = "UseClusterDefaultCapacityProviders"
-USE_CLUSTER_CAPACITY_PROVIDERS_CON = Equals(
-    Ref(ecs_params.LAUNCH_TYPE), ecs_params.LAUNCH_TYPE.Default
+USE_CLUSTER_CAPACITY_PROVIDERS_CON = Not(Equals(Ref(ecs_params.LAUNCH_TYPE), "EC2"))
+
+NOT_USE_CLUSTER_CAPACITY_PROVIDERS_CON_T = "UseCustomCapacityProvidersCon"
+NOT_USE_CLUSTER_CAPACITY_PROVIDERS_CON = Equals(
+    Ref(ecs_params.LAUNCH_TYPE), "CAPACITY_PROVIDERS"
 )
 
 CREATE_CLUSTER_CON_T = "CreateClusterCondition"
