@@ -418,6 +418,7 @@ class Service(object):
             DeploymentController=DeploymentController(
                 Type=Ref(ecs_params.ECS_CONTROLLER)
             ),
+            CapacityProviderStrategy=Ref(AWS_NO_VALUE),
             EnableECSManagedTags=True,
             DesiredCount=If(
                 ecs_conditions.SERVICE_COUNT_ZERO_AND_FARGATE_CON_T,
@@ -454,9 +455,13 @@ class Service(object):
             ),
             TaskDefinition=Ref(family.task_definition),
             LaunchType=If(
-                ecs_conditions.USE_CLUSTER_CAPACITY_PROVIDERS_CON_T,
+                ecs_conditions.NOT_USE_CLUSTER_CAPACITY_PROVIDERS_CON_T,
                 Ref(AWS_NO_VALUE),
-                Ref(ecs_params.LAUNCH_TYPE),
+                If(
+                    ecs_conditions.USE_CLUSTER_CAPACITY_PROVIDERS_CON_T,
+                    Ref(ecs_params.LAUNCH_TYPE),
+                    Ref(AWS_NO_VALUE),
+                ),
             ),
             Tags=Tags(
                 {
