@@ -10,7 +10,13 @@ from compose_x_common.compose_x_common import keyisset
 
 from ecs_composex.common import LOG
 from ecs_composex.kinesis.kinesis_aws import lookup_stream_config
-from ecs_composex.kinesis.kinesis_params import STREAM_ARN, STREAM_ID, STREAM_KMS_KEY_ID
+from ecs_composex.kinesis.kinesis_params import (
+    MAPPINGS_KEY,
+    RES_KEY,
+    STREAM_ARN,
+    STREAM_ID,
+    STREAM_KMS_KEY_ID,
+)
 from ecs_composex.resource_settings import (
     handle_lookup_resource,
     handle_resource_to_services,
@@ -39,25 +45,34 @@ def create_kinesis_mappings(mapping, resources, settings):
 
 def kinesis_to_ecs(resources, services_stack, res_root_stack, settings):
     """
-    Function to apply SQS settings to ECS Services
+    Function to apply Kinesis settings to ECS Services
     :return:
     """
-    resource_mappings = {}
     new_resources = [
-        resources[res_name] for res_name in resources if not resources[res_name].lookup
+        resources[res_name]
+        for res_name in resources
+        if resources[res_name].cfn_resource
     ]
     lookup_resources = [
-        resources[res_name] for res_name in resources if resources[res_name].lookup
+        resources[res_name] for res_name in resources if resources[res_name].mappings
     ]
     if new_resources and new_resources not in services_stack.DependsOn:
         services_stack.DependsOn.append(res_root_stack.title)
         LOG.info(f"Added dependency between services and {res_root_stack.title}")
     for new_res in new_resources:
         handle_resource_to_services(
-            new_res, services_stack, res_root_stack, settings, STREAM_ARN, [STREAM_ID]
+            new_res,
+            services_stack,
+            res_root_stack,
+            settings,
+            STREAM_ARN,
+            [STREAM_ID],
         )
-    create_kinesis_mappings(resource_mappings, lookup_resources, settings)
     for lookup_res in lookup_resources:
         handle_lookup_resource(
-            resource_mappings, "kinesis", lookup_res, STREAM_ARN, [STREAM_ID]
+            settings.mappings[RES_KEY],
+            MAPPINGS_KEY,
+            lookup_res,
+            STREAM_ARN,
+            [STREAM_ID],
         )
