@@ -8,7 +8,7 @@ Module to manage IAM policies to grant access to ECS Services to KMS Keys
 
 from ecs_composex.common import LOG
 from ecs_composex.kms.kms_aws import lookup_key_config
-from ecs_composex.kms.kms_params import KMS_KEY_ARN, KMS_KEY_ID
+from ecs_composex.kms.kms_params import KMS_KEY_ARN, KMS_KEY_ID, MAPPINGS_KEY, RES_KEY
 from ecs_composex.resource_settings import (
     handle_lookup_resource,
     handle_resource_to_services,
@@ -34,22 +34,31 @@ def kms_to_ecs(resources, services_stack, res_root_stack, settings):
     Function to apply SQS settings to ECS Services
     :return:
     """
-    resources_mappings = {}
     new_resources = [
-        resources[res_name] for res_name in resources if not resources[res_name].lookup
+        resources[res_name]
+        for res_name in resources
+        if resources[res_name].cfn_resource
     ]
     lookup_resources = [
-        resources[res_name] for res_name in resources if resources[res_name].lookup
+        resources[res_name] for res_name in resources if resources[res_name].mappings
     ]
     if new_resources and res_root_stack.title not in services_stack.DependsOn:
         services_stack.DependsOn.append(res_root_stack.title)
         LOG.info(f"Added dependency between services and {res_root_stack.title}")
     for new_res in new_resources:
         handle_resource_to_services(
-            new_res, services_stack, res_root_stack, settings, KMS_KEY_ARN, [KMS_KEY_ID]
+            new_res,
+            services_stack,
+            res_root_stack,
+            settings,
+            KMS_KEY_ARN,
+            [KMS_KEY_ID],
         )
-    create_kms_mappings(resources_mappings, lookup_resources, settings)
     for lookup_res in lookup_resources:
         handle_lookup_resource(
-            resources_mappings, "kms", lookup_res, KMS_KEY_ARN, [KMS_KEY_ID]
+            settings.mappings[RES_KEY],
+            MAPPINGS_KEY,
+            lookup_res,
+            KMS_KEY_ARN,
+            [KMS_KEY_ID],
         )
